@@ -4,19 +4,19 @@
 (*                                                                     *)
 (*            Jun Furuse, projet Cristal, INRIA Rocquencourt           *)
 (*                                                                     *)
-(*  Copyright 1999-2004,                                               *)
+(*  Copyright 1999,2000,2001,2002,2001,2002                            *)
 (*  Institut National de Recherche en Informatique et en Automatique.  *)
 (*  Distributed only by permission.                                    *)
 (*                                                                     *)
 (***********************************************************************)
+open OImage
 
-(* $Id: oBmp.ml,v 1.7 2004/09/07 07:31:01 weis Exp $ *)
-
-open OImages;;
-
-let load name opts = OImages.make (Bmp.load name opts);;
+let load name opts =
+  OImage.make (Bmp.load name opts)
+;;
 
 let save name opts image =
   match image#image_class with
   | ClassRgb24 | ClassIndex8 -> Bmp.save name opts image#image
-  | _ -> raise Wrong_image_class;;
+  | _ -> raise Wrong_image_class
+;;
