@@ -6,14 +6,12 @@
 (*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
 (*            Jun Furuse, projet Cristal, INRIA Rocquencourt           *)
 (*                                                                     *)
-(*  Copyright 1999-2004,                                               *)
+(*  Copyright 1999,2000,2001,2002,2001,2002                            *)
 (*  Institut National de Recherche en Informatique et en Automatique.  *)
 (*  Distributed only by permission.                                    *)
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: rgb24.ml,v 1.20 2004/09/07 07:31:02 weis Exp $ *)
-
 module E = struct
   open Color
   type t = Color.rgb
@@ -30,16 +28,16 @@ module E = struct
     let str = String.create bytes_per_pixel in
     set str 0 t;
     str
-end;;
+end
 
-module RI = Genimage.MakeRawImage(E);;
+module RI = Genimage.MakeRawImage(E)
 
-type rawimage = RI.t;;
-type elt = Color.rgb;;
+type rawimage = RI.t
+type elt = Color.rgb
 type t = { width : int;
 	   height : int;
 	   rawimage : RI.t;
-	   mutable infos : Info.info list };;
+	   mutable infos : Info.info list }
 
 module C = struct
   type rawimage = RI.t
@@ -55,36 +53,37 @@ module C = struct
       height= height;
       rawimage = rawimage;
       infos= src.infos }
-end;;
+end
 
-module IMAGE = Genimage.Make(RI)(C);;
+module IMAGE = Genimage.Make(RI)(C)
 
 let create_with width height infos data =
   { width= width;
     height= height;
     rawimage= RI.create_with width height data;
-    infos= infos };;
+    infos= infos } 
+;;
 
-let rawimage = C.rawimage;;
-let create = IMAGE.create;;
-let make = IMAGE.make;;
-let dump = IMAGE.dump;;
-let unsafe_access = IMAGE.unsafe_access;;
-let get_strip = IMAGE.get_strip;;
-let set_strip = IMAGE.set_strip;;
-let get_scanline = IMAGE.get_scanline;;
-let set_scanline = IMAGE.set_scanline;;
-let unsafe_get = IMAGE.unsafe_get;;
-let unsafe_set = IMAGE.unsafe_set;;
-let get = IMAGE.get;;
-let set = IMAGE.set;;
-let destroy = IMAGE.destroy;;
-let copy = IMAGE.copy;;
-let sub = IMAGE.sub;;
-let blit = IMAGE.blit;;
-let map = IMAGE.map;;
+let rawimage = C.rawimage
+let create = IMAGE.create
+let make = IMAGE.make
+let dump = IMAGE.dump
+let unsafe_access = IMAGE.unsafe_access
+let get_strip = IMAGE.get_strip
+let set_strip = IMAGE.set_strip
+let get_scanline = IMAGE.get_scanline
+let set_scanline = IMAGE.set_scanline
+let unsafe_get = IMAGE.unsafe_get
+let unsafe_set = IMAGE.unsafe_set
+let get = IMAGE.get
+let set = IMAGE.set
+let destroy = IMAGE.destroy
+let copy = IMAGE.copy
+let sub = IMAGE.sub
+let blit = IMAGE.blit
+let map = IMAGE.map
 
-open Color;;
+open Color
 
 (* image resize with smoothing *)
 (* good result for reducing *)
@@ -132,7 +131,8 @@ let resize_reduce prog img nw nh =
       Some p -> p (float (x + 1) /. float nw)
     | None -> ()
   done;
-  newimage;;
+  newimage
+;;
 
 let resize_enlarge prog img nw nh =
   let newimage = create nw nh in
@@ -247,7 +247,8 @@ let resize_enlarge prog img nw nh =
     | None -> ()
 
   done;
-  newimage;;
+  newimage
+;;
 
 let resize prog img nw nh =
   let xscale = float nw /. float img.width in  
@@ -334,7 +335,8 @@ let to_rgba32 t =
 	  alpha= 255 }
     done
   done;
-  rgba32;;
+  rgba32
+;;
 
 let of_rgba32 t =
   let rgb24 = create t.Rgba32.width t.Rgba32.height in
@@ -344,4 +346,5 @@ let of_rgba32 t =
 	(let { color= c } = Rgba32.unsafe_get t x y in c)
     done
   done;
-  rgb24;;
+  rgb24
+;;
