@@ -4,38 +4,39 @@
 (*                                                                     *)
 (*            Jun Furuse, projet Cristal, INRIA Rocquencourt           *)
 (*                                                                     *)
-(*  Copyright 1999-2004,                                               *)
+(*  Copyright 1999,2000,2001,2002,2001,2002                            *)
 (*  Institut National de Recherche en Informatique et en Automatique.  *)
 (*  Distributed only by permission.                                    *)
 (*                                                                     *)
 (***********************************************************************)
+open Image
+open OImage
+open Info
 
-(* $Id: monochrome.ml,v 1.6 2004/09/21 18:15:47 weis Exp $ *)
+let _ =
+  let files = ref [] in
+  Arg.parse [] (fun s -> files := s :: !files) "monochrome src dst";
+  let src,dst = 
+    match List.rev !files with
+    | [src; dst] -> src, dst
+    | _ -> raise (Invalid_argument "you need two arguments")
+  in
+  
+  let src = OImage.rgb24 (OImage.load src []) in
 
-open Images;;
-open OImages;;
-open Info;;
-
-let files = ref [] in
-Arg.parse [] (fun s -> files := s :: !files) "monochrome src dst";
-let src, dst =
-  match List.rev !files with
-  | [src; dst] -> src, dst
-  | _ -> invalid_arg "you need two arguments" in
-
-let src = OImages.rgb24 (OImages.load src []) in
-
-let mono img =
-  (* Make monochrome *)
-  for x = 0 to src#width - 1 do
-    for y = 0 to src#height - 1 do
-      let rgb = src#get x y in
-      let mono = Color.brightness rgb in
-      src#set x y {r= mono; g= mono; b= mono}
+  let mono img = 
+    (* Make monochrome *)
+    for x = 0 to src#width - 1 do
+      for y = 0 to src#height - 1 do
+	let rgb = src#get x y in
+	let mono = Color.brightness rgb in
+	src#set x y {r= mono; g= mono; b= mono}
+      done
     done
-  done in
-
-let saver img = img#save dst None [] in
-
-mono src;
-saver src;;
+  in
+  
+  let saver img = img#save dst None [] in
+  
+  mono src;
+  saver src
+;;  
