@@ -6,20 +6,18 @@
 (*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
 (*            Jun Furuse, projet Cristal, INRIA Rocquencourt           *)
 (*                                                                     *)
-(*  Copyright 1999-2004,                                               *)
+(*  Copyright 1999,2000,2001,2002,2001,2002                            *)
 (*  Institut National de Recherche en Informatique et en Automatique.  *)
 (*  Distributed only by permission.                                    *)
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: xpm.mli,v 1.6 2004/09/07 07:31:08 weis Exp $ *)
+val check_header : string -> Image.header
+  (* Checks the file header *)
 
-val check_header : string -> Images.header;;
-  (** Checks the file header *)
-
-val load : string -> Images.load_option list -> Images.t;;
-  (** Loads an xpm image. *)
+val load : string -> Image.load_option list -> Image.t
+  (* Loads an xpm image. *)
 
 (* NO SAVE 
-  val save : string -> Images.save_option list -> Images.t -> unit *)
+  val save : string -> Image.save_option list -> Image.t -> unit *)
  
